@@ -5,6 +5,10 @@ or CSS selectors
 
 __author__ = 'Scrapy project'
 __email__ = 'info@scrapy.org'
-__version__ = '1.0.3'
+__version__ = '1.4.0'
 
 from parsel.selector import Selector, SelectorList  # NOQA
+from parsel.csstranslator import css2xpath  # NOQA
+from parsel import xpathfuncs # NOQA
+
+xpathfuncs.setup()
