@@ -3,6 +3,8 @@ import re
 import weakref
 import six
 import unittest
+import pickle
+
 from parsel import Selector
 
 
@@ -10,6 +12,19 @@ class SelectorTestCase(unittest.TestCase):
 
     sscls = Selector
 
+    def test_pickle_selector(self):
+        sel = self.sscls(text=u'<html><body><p>some text</p></body></html>')
+        self.assertRaises(TypeError, lambda s: pickle.dumps(s, protocol=2), sel)
+
+    def test_pickle_selector_list(self):
+        sel = self.sscls(text=u'<html><body><ul><li>1</li><li>2</li><li>3</li></ul></body></html>')
+        sel_list = sel.css('li')
+        empty_sel_list = sel.css('p')
+        self.assertIsInstance(sel_list, self.sscls.selectorlist_cls)
+        self.assertIsInstance(empty_sel_list, self.sscls.selectorlist_cls)
+        self.assertRaises(TypeError, lambda s: pickle.dumps(s, protocol=2), sel_list)
+        self.assertRaises(TypeError, lambda s: pickle.dumps(s, protocol=2), empty_sel_list)
+
     def test_simple_selection(self):
         """Simple selector tests"""
         body = u"<p><input name='a'value='1'/><input name='b'value='2'/></p>"
@@ -588,8 +603,10 @@ class SelectorTestCase(unittest.TestCase):
 """
         sel = self.sscls(text=xml, type='xml')
         self.assertEqual(len(sel.xpath("//link")), 0)
+        self.assertEqual(len(sel.xpath("./namespace::*")), 3)
         sel.remove_namespaces()
         self.assertEqual(len(sel.xpath("//link")), 2)
+        self.assertEqual(len(sel.xpath("./namespace::*")), 1)
 
     def test_remove_attributes_namespaces(self):
         xml = u"""<?xml version="1.0" encoding="UTF-8"?>
